# Computing thawing index
# if input air temperature variablename: Thawing degree-days of air (Celsius degree-days)
# if input ground temperature variablename: Thawing degree-days of ground surface (Celsius degree-days)

Thawing_index <- function(Year, TempName, data=QTP_ATM) {
  
  ti <- sapply(Year, function(Year) tryCatch({
    abs(tapply(data[TempName][data[TempName] > 0 & data$Year==Year], 
                     data$Year[data[TempName] > 0 & data$Year==Year], sum, na.rm=T))
  }, error = function ( e ) {ti <- NA}
  , warning = function ( e ) {ti <- NA}
  ), simplify=T)
  
  idx <- !(sapply(ti, length))
  ti[idx] <- NA
  ti <- unlist(ti)
  
  names(ti) <- Year
  return(ti)
}

# computing Freezing index
# if input air temperature variablename: Freezing degree-days of air (Celsius degree-days) 
# if input ground temperature variablename: Freezing degree-days of ground surface (Celsius degree-days)

Freezing_index <- function(Year, TempName, data=QTP_ATM) {
  
  fi <- sapply(Year, function(Year) tryCatch({
    abs(tapply(data[TempName][data[TempName] <= 0 & data$Year==Year], 
               data$Year[data[TempName] <= 0 & data$Year==Year], sum, na.rm=T))
  }, error = function ( e ) {fi <- NA}
    , warning = function ( e ) {fi <- NA}
  ), simplify=T)
  
  idx <- !(sapply(fi, length))
  fi[idx] <- NA
  fi <- unlist(fi)
  
  names(fi) <- Year
  return(fi)
}


# Computing mean annual air temperature (MAAT)

MAAT <- function(Year, TempName="Temperature", data=QTP_ATM) {
  
  maat <- sapply(Year, function(Year) tryCatch({
    (Thawing_index(Year=Year, TempName=TempName, data=data) - 
             Freezing_index(Year=Year, TempName=TempName, data=data))/365
  }, error = function ( e ) {maat <- NA}
    , warning = function ( e ) {maat <- NA}
  ), simplify=T)
  
  names(maat) <- Year
  return(maat)
}
